@@ -15,7 +15,7 @@ def BeakerSessionFactoryConfig(**options):
     class PyramidBeakerSessionObject(SessionObject):
         implements(ISession)
         _options = options
-        _cookie_on_exception = _options.pop('cookie_on_exception', False)
+        _cookie_on_exception = _options.pop('cookie_on_exception', True)
         def __init__(self, request):
             SessionObject.__init__(self, request.environ, **self._options)
             def session_callback(request, response):
@@ -151,3 +151,8 @@ def set_cache_regions_from_settings(settings):
             if 'url' not in region_settings:
                 region_settings['url'] = cache_settings.get('url')
             cache.cache_regions[region] = region_settings
+
+def includeme(config):
+    session_factory = session_factory_from_settings(config.registry.settings)
+    config.set_session_factory(session_factory)
+    set_cache_regions_from_settings(config.registry.settings)
